<template>
  <div class="table-page">
    <div class="table-page-content">
      <div class="right-table">
        <div class="full-page bg">
          <div class="search-box">
            <SearchCommon :optionList="optionList" @search="handleSearch" />
          </div>
          <div class="main-table-container">
            <div class="table-container" style="padding: 20px">
              <div ref="tableRef" class="table-content">
                <el-table ref="multipleSelection" v-loading="tableLoading" :data="tableData"
                          :max-height="tableMaxHeight" border class="table-list"
                          element-loading-background="rgba(10 ,38 ,61, 0.9)"
                          row-key="id"
                          stripe @select="handleSelection" @selection-change="handleSelectionChange">
                  <el-table-column align="center" label="序号" type="index" width="60" />
                  <el-table-column align="center" label="接收时间" min-width="80" prop="receiveTime"
                                   show-overflow-tooltip />
                  <el-table-column align="center" label="报案电话" min-width="80" prop="rescueTel"
                                   show-overflow-tooltip>
                  </el-table-column>
                  <el-table-column align="center" label="报案时间" min-width="80" prop="rescueTime" show-overflow-tooltip>
                  </el-table-column>
                  <el-table-column align="center" label="救援类型" min-width="80" prop="rescueType" show-overflow-tooltip>
                    <template v-slot="{ row }">
                      {{ dictionaryEscape('jylx', row.rescueType + '') || '-' }}
                    </template>
                  </el-table-column>
                  <el-table-column align="center" label="所属路段" min-width="80" prop="roadName"
                                   show-overflow-tooltip />
                  <el-table-column align="center" label="事件上报部门" min-width="80" prop="uploadTeamName"
                                   show-overflow-tooltip>
                  </el-table-column>
                  <el-table-column align="center" label="现场情况" min-width="80" prop="sceneInfo" show-overflow-tooltip>
                    <template v-slot="{ row }">
                      {{ dictionaryEscape('xcqk', row.sceneInfo + '') || '-' }}
                    </template>
                  </el-table-column>
                  <el-table-column align="center" label="核实状态" width="80" prop="status">
                    <template v-slot="{row}">
                      <el-link v-if="row.status < 2" :underline="false" type="warning">
                        未核实登记
                      </el-link>
                      <el-link v-else :underline="false" type="success">
                        已核实登记
                      </el-link>
                    </template>
                  </el-table-column>
                  <el-table-column align="center" label="操作" min-width="80" show-overflow-tooltip>
                    <template v-slot="{ row }">
                      <el-link :underline="false" type="warning" @click="changePage('DetailPage', row, '核实')">
                        核实
                      </el-link>
                      <el-link :underline="false" type="primary" @click="handleDetailPage(row)">
                        详情
                      </el-link>
                    </template>
                  </el-table-column>
                </el-table>
                <pagination ref="paginationPanel" :pageResult="params.pageBean" style="margin-top: 10px"
                            @size-change="handleSizeChange" @current-change="handleCurrentChange" />
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>

    <!--  目录树修改新增弹层  -->
    <tree-dialog :id.sync="treeItemId" :is-show.sync="treeDialog" :parent-id.sync="treeItemParentId"
                 @catalogChange="catalogChange" />
  </div>
</template>

<script>
import {dictionaryEscape,getDictionaryByCode} from '@/utils/dictionary'
import {refineRequestBody, setQueryValue} from '@/utils/requestWrappers'
import pagination from '@/components/SuperPagination/index.vue'
import {TableMixin} from '@/mixins/tableMixin'
import treeSide from '@/components/treeSide/index.vue'
import SearchCommon from '@/components/SearchCommon/index.vue'
import {tableData} from '@/api/patrolAndRescue/obstacleClearingRescue/reportRescueQuery'
import TreeDialog from './components/TreeDialog/index.vue'
import PubSub from 'pubsub-js'


export default {
  name: 'TablePage',
  components: {
    TreeDialog,
    pagination,
    treeSide,
    SearchCommon
  },
  mixins: [TableMixin],
  data() {
    return {
      pubSub: null,
      tableMaxHeight: '600px',
      loading: false,
      tableLoading: false,
      treeData: [], //左边树
      tabList: ['政策法规'], //左边tab
      defaultProps: {
        children: 'children',
        label: 'name'
      },
      tableData: [],
      currentDataDel: [],
      optionList: [
        {title: '事件类型', prop: ['event_Type_'], type: 'select', option: getDictionaryByCode('sjlx'), multiple: false},
        {title: '事件来源', prop: ['event_Src_'], type: 'select',option: getDictionaryByCode('sjly'), multiple: false},
        {title: '所属路段', prop: ['road_Name_'], type: 'input', default: true},
      ],
      params: {
        pageBean: {pageSize: 20, page: 1, total: 0},
        querys: [
          {operation: 'EQUAL', property: 'event_Type_', value: ''},
          {operation: 'EQUAL', property: 'event_Src_', value: ''},
          {operation: 'LIKE', property: 'road_Name_', value: ''}
        ],
        sorter: []
      },
      treeDialog: false, // 科目信息弹层
      treeItemId: '', // 树形目录id
      treeItem: {}, // 树形节点选中对象
      treeItemParentId: '' // 树形目录父级id
    }
  },
  created() {
    // 获取树形目录
    // this.getTreeData(treeData => {
    //   // 回调中默认选中第一项并将其id作为参数请求表格
    //   this.treeItem = treeData[0] || {}
    //   this.$nextTick(_ => {
    //     this.$refs.treeSide?.setCurrentKey(treeData[0]?.id)
    //   })
    //   setQueryValue(this.params, 'catalog_full_id_ ', treeData[0]?.id || '')
    //   this.loadData()
    // })
    this.loadData()
  },
  mounted() {
    this.pubSub = PubSub.subscribe('TablePage', (_, data) => {
      switch (data.type) {
        case 'add':
          this.params.pageBean.page = 1
          this.loadData()
          break
        case 'edit':
          this.loadData()
          break
      }
    })

  },
  methods: {
    dictionaryEscape,
    //获取科目树
    async getTreeData(callback) {
      this.treeData = [{
        name: '规章制度',
        edit: 1,
        id: '',
        parentId: '',
        children: await getTree('3')
      }]
      // 保证重新刷新树数据后，选中效果不失效
      if (this.treeItem.id) {
        this.$nextTick(_ => {
          this.$refs.treeSide?.setCurrentKey(this.treeItem.id)
        })
      }
      callback && callback(this.treeData)
    },

    //获取数据
    async loadData() {
      this.tableLoading = true
      const {total = 0, rows = []} = await tableData(refineRequestBody(this.params))
      this.params.pageBean.total = total
      this.tableData = rows
      this.tableLoading = false
    },

    //左边树节点
    currentChange(nodeItem) {
      // 修改对应的字段值
      setQueryValue(this.params, 'catalog_full_id_ ', nodeItem?.id || '')
      this.treeItem = nodeItem || {}
      this.calcTableHeight(500)
      this.params.pageBean.page = 1
      this.loadData()
    },

    // 树节点操作
    operateEvent(type, data) {
      switch (type) {
        case '新增':
          this.treeItemParentId = data.id
          this.treeDialog = true
          break
        case '编辑':
          this.treeItemId = data.id
          this.treeItemParentId = data.parentId
          this.treeDialog = true
          break
        case '删除':
          this.$confirm('确定删除选中资料分类吗？', '提示', {
            confirmButtonText: '确认',
            cancelButtonText: '取消',
            type: 'warning'
          }).then(async () => {
            const {state} = await treeDelete(data.id)
            if (state) {
              this.$message.success(`删除资料分类成功`)
            } else {
              this.$message.error(`删除资料分类失败`)
            }
            await this.getTreeData()
          }).catch(_ => _)
          break
      }
    },

    // 目录改变
    catalogChange(dialogName) {
      this.getTreeData(_ => this[dialogName] = false)
    },

    //修改
    handleDbClick(row) {
      if (this.clickTimer) return (this.clickTimer = false)
      if (!row.edit) return
      this.changePage('EditAddPage', row)
    },

    // 改变页面
    changePage(pageName = '', row = {}, type = '') {
      if (!pageName) return
      if (type=='核实'&&row.status > 1) {
        this.$message.warning('救援信息已核实登记')
        return
      }
      this.$emit('changePage', pageName, _ => {
        PubSub.publish(pageName, row)
      }, type || '详情')
    }
  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    PubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped></style>
